@@ -18,6 +18,7 @@ import datetime
 from oslo_config import cfg
 from oslo_db.sqlalchemy import session as db_session
 from oslo_db.sqlalchemy import utils as db_utils
+import six
 import sqlalchemy
 from sqlalchemy.engine.url import make_url
 
@@ -45,7 +46,7 @@ def _create_facade_lazily():
     if facade is None:
         facade = db_session.EngineFacade(
             CONF.database.connection,
-            **dict(CONF.database.iteritems()))
+            **dict(six.iteritems(CONF.database)))
         _facades[db_backend] = facade
     return facade
 
@@ -83,6 +84,19 @@ def _filter_runs_by_date(query, start_date=None, stop_date=None):
     return query
 
 
+def _filter_test_runs_by_date(query, start_date=None, stop_date=None):
+    # Helper to apply a data range filter to a query on Run table
+    if isinstance(start_date, str):
+        start_date = datetime.datetime.strptime(start_date, '%Y-%m-%d')
+    if isinstance(stop_date, str):
+        stop_date = datetime.datetime.strptime(stop_date, '%Y-%m-%d')
+    if start_date:
+        query = query.filter(models.TestRun.start_time >= start_date)
+    if stop_date:
+        query = query.filter(models.TestRun.start_time <= stop_date)
+    return query
+
+
 def get_engine(use_slave=False):
     """Get a new sqlalchemy engine instance
 
@@ -165,13 +179,15 @@ def create_run(skips=0, fails=0, passes=0, run_time=0, artifacts=None,
     :param str id: the run id for the new run, needs to be a unique value
     :param session: optional session object if one isn't provided a new session
                     will be acquired for the duration of this operation
+    :param run_at: optional time at which the run was started. If not specified
+                   the time that data is added to the DB will be used instead
 
     :return: The run object stored in the DB
     :rtype: subunit2sql.models.Run
     """
     run = models.Run()
     if id:
-        run.id = id
+        run.uuid = id
     if run_at:
         run.run_at = run_at
     run.skips = skips
@@ -274,8 +290,8 @@ def get_run_metadata(run_id, session=None):
     :rtype: subunit2sql.models.RunMetadata
     """
     session = session or get_session()
-    query = db_utils.model_query(models.RunMetadata, session).filter_by(
-        run_id=run_id)
+    query = db_utils.model_query(models.RunMetadata, session).join(
+        models.RunMetadata.run).filter(models.Run.uuid == run_id)
     return query.all()
 
 
@@ -561,10 +577,25 @@ def get_test_by_test_id(test_id, session=None):
     return test
 
 
-def get_run_by_id(id, session=None):
-    """Get an individual run by it's uuid.
+def get_run_id_from_uuid(uuid, session=None):
+    """Get the id for a run by it's uuid
 
-    :param str id: The uuid for the run (the id field in the DB)
+    :param str uuid: The uuid for the run
+    :param session: optional session object if one isn't provided a new session
+                    will be acquired for the duration of this operation
+    :return: The id for the run with the provided uuid
+    :rtype: int
+    """
+    session = session or get_session()
+    run_id = session.query(models.Run.id).filter(
+        models.Run.uuid == uuid).first()[0]
+    return run_id
+
+
+def get_run_by_id(id, session=None):
+    """Get an individual run by it's id.
+
+    :param str id: The id for the run
     :param session: optional session object if one isn't provided a new session
                     will be acquired for the duration of this operation
 
@@ -577,9 +608,9 @@ def get_run_by_id(id, session=None):
 
 
 def get_test_run_by_id(test_run_id, session=None):
-    """Get an individual test run by it's uuid.
+    """Get an individual test run by it's id.
 
-    :param str test_run_id: The uuid for the test run (the id field in the DB)
+    :param str test_run_id: The id for the test run
     :param session: optional session object if one isn't provided a new session
                     will be acquired for the duration of this operation
 
@@ -610,11 +641,43 @@ def get_test_runs_by_test_id(test_id, session=None):
     return test_runs
 
 
+def get_test_runs_by_test_test_id(test_id, start_date=None, stop_date=None,
+                                  session=None):
+    """Get all test runs for a specific test by the test'stest_id column
+
+    :param str test_id: The test's test_id (the test_id column in the test
+                        table) which to get all test runs for
+    :param session: optional session object if one isn't provided a new session
+                    will be acquired for the duration of this operation
+    :param datetime.datetime start_date: The date to use as the start date for
+                                         results
+    :param datetime.datetime stop_date: The date to use as the cutoff date for
+                                        results
+
+    :return list: The list of test run objects for the specified test
+    :rtype: subunit2sql.models.TestRun
+    """
+    session = session or get_session()
+
+    test_runs_query = db_utils.model_query(models.TestRun,
+                                           session=session).join(
+        models.Test).filter(
+            models.Test.test_id == test_id)
+    if start_date:
+        test_runs_query = test_runs_query.filter(
+            models.TestRun.start_time >= start_date)
+    if stop_date:
+        test_runs_query = test_runs_query.filter(
+            models.TestRun.start_time <= stop_date)
+    test_runs = test_runs_query.all()
+    return test_runs
+
+
 def get_test_runs_by_run_id(run_id, session=None):
     """Get all test runs for a specific run.
 
-    :param str run_id: The run's uuid (the id column in the run table) which to
-                        get all test runs for
+    :param str run_id: The run's uuid (the uuid column in the run table) which
+                       to get all test runs for
     :param session: optional session object if one isn't provided a new session
                     will be acquired for the duration of this operation
 
@@ -622,9 +685,10 @@ def get_test_runs_by_run_id(run_id, session=None):
     :rtype: subunit2sql.models.TestRun
     """
     session = session or get_session()
-    test_runs = db_utils.model_query(models.TestRun,
-                                     session=session).filter_by(
-        run_id=run_id).all()
+    test_runs = db_utils.model_query(
+        models.TestRun, session=session).join(
+            models.Run).filter(
+                models.Run.uuid == run_id).all()
     return test_runs
 
 
@@ -686,18 +750,19 @@ def get_tests_run_dicts_from_run_id(run_id, session=None):
     """
     session = session or get_session()
     query = db_utils.model_query(models.Test, session=session).join(
-        models.TestRun).filter(models.TestRun.run_id == run_id).outerjoin(
-            models.TestRunMetadata).order_by(
-                models.TestRun.start_time,
-                models.TestRun.start_time_microsecond).values(
-                    models.Test.test_id,
-                    models.TestRun.status,
+        models.TestRun).join(models.Run).filter(
+            models.Run.uuid == run_id).outerjoin(
+                models.TestRunMetadata).order_by(
                     models.TestRun.start_time,
-                    models.TestRun.start_time_microsecond,
-                    models.TestRun.stop_time,
-                    models.TestRun.stop_time_microsecond,
-                    models.TestRunMetadata.key,
-                    models.TestRunMetadata.value)
+                    models.TestRun.start_time_microsecond).values(
+                        models.Test.test_id,
+                        models.TestRun.status,
+                        models.TestRun.start_time,
+                        models.TestRun.start_time_microsecond,
+                        models.TestRun.stop_time,
+                        models.TestRun.stop_time_microsecond,
+                        models.TestRunMetadata.key,
+                        models.TestRunMetadata.value)
     test_runs = collections.OrderedDict()
     for test_run in query:
         if test_run[0] not in test_runs:
@@ -820,7 +885,7 @@ def get_recent_successful_runs(num_runs=10, session=None):
     session = session or get_session()
     results = db_utils.model_query(models.Run, session).order_by(
         models.Run.run_at.desc()).filter_by(fails=0).limit(num_runs).all()
-    return map(lambda x: x.id, results)
+    return list(map(lambda x: x.uuid, results))
 
 
 def get_recent_failed_runs(num_runs=10, session=None):
@@ -836,7 +901,7 @@ def get_recent_failed_runs(num_runs=10, session=None):
     results = db_utils.model_query(models.Run, session).order_by(
         models.Run.run_at.desc()).filter(
         models.Run.fails > 0).limit(num_runs).all()
-    return map(lambda x: x.id, results)
+    return list(map(lambda x: x.uuid, results))
 
 
 def delete_old_runs(expire_age=186, session=None):
@@ -1008,8 +1073,8 @@ def get_test_run_dict_by_run_meta_key_value(key, value, start_date=None,
             models.TestRun,
             models.RunMetadata.run_id == models.TestRun.run_id).join(
                 models.Test)
-    query = _filter_runs_by_date(query, start_date=start_date,
-                                 stop_date=stop_date)
+    query = _filter_test_runs_by_date(query, start_date=start_date,
+                                      stop_date=stop_date)
     query = query.values(models.Test.test_id,
                          models.TestRun.status,
                          models.TestRun.start_time,
@@ -1072,7 +1137,7 @@ def get_all_runs_time_series_by_key(key, start_date=None,
                 'skip': run[3],
             }]}
         else:
-            if run[4] not in runs[run[0]].keys():
+            if run[4] not in list(runs[run[0]].keys()):
                 runs[run[0]][run[4]] = [{
                     'pass': run[1],
                     'fail': run[2],
@@ -1110,7 +1175,7 @@ def get_time_series_runs_by_key_value(key, value, start_date=None,
     run_query = db_utils.model_query(models.Run, session).join(
         models.RunMetadata).filter(models.Run.id.in_(sub_query))
     run_query = _filter_runs_by_date(run_query, start_date, stop_date)
-    run_query = run_query.values(models.Run.id,
+    run_query = run_query.values(models.Run.uuid,
                                  models.Run.passes,
                                  models.Run.fails,
                                  models.Run.skips,
