@@ -14,6 +14,7 @@
 
 import datetime
 
+from six import moves
 import testscenarios
 
 from subunit2sql.db import api
@@ -69,7 +70,7 @@ class TestDatabaseAPI(base.TestCase):
         stop_time = datetime.datetime.utcnow()
         api.create_test_run(test_a.id, run.id, 'success',
                             start_time, stop_time)
-        test_run_dict = api.get_tests_run_dicts_from_run_id(run.id)
+        test_run_dict = api.get_tests_run_dicts_from_run_id(run.uuid)
         self.assertEqual(1, len(test_run_dict))
         self.assertIn('fake_test', test_run_dict)
         self.assertEqual(test_run_dict['fake_test']['status'], 'success')
@@ -84,7 +85,7 @@ class TestDatabaseAPI(base.TestCase):
         stop_time = None
         api.create_test_run(test_a.id, run.id, 'success',
                             start_time, stop_time)
-        test_run_dict = api.get_tests_run_dicts_from_run_id(run.id)
+        test_run_dict = api.get_tests_run_dicts_from_run_id(run.uuid)
         self.assertEqual(1, len(test_run_dict))
         self.assertIn('fake_test', test_run_dict)
         self.assertEqual(test_run_dict['fake_test']['status'], 'success')
@@ -98,7 +99,7 @@ class TestDatabaseAPI(base.TestCase):
         start_time = None
         api.create_test_run(test_a.id, run.id, 'success',
                             start_time, stop_time)
-        test_run_dict = api.get_tests_run_dicts_from_run_id(run.id)
+        test_run_dict = api.get_tests_run_dicts_from_run_id(run.uuid)
         self.assertEqual(1, len(test_run_dict))
         self.assertIn('fake_test', test_run_dict)
         self.assertEqual(test_run_dict['fake_test']['status'], 'success')
@@ -112,7 +113,7 @@ class TestDatabaseAPI(base.TestCase):
         start_time = None
         api.create_test_run(test_a.id, run.id, 'success',
                             start_time, stop_time)
-        test_run_dict = api.get_tests_run_dicts_from_run_id(run.id)
+        test_run_dict = api.get_tests_run_dicts_from_run_id(run.uuid)
         self.assertEqual(1, len(test_run_dict))
         self.assertIn('fake_test', test_run_dict)
         self.assertEqual(test_run_dict['fake_test']['status'], 'success')
@@ -131,7 +132,7 @@ class TestDatabaseAPI(base.TestCase):
             'attrs': 'test,smoke,notatest',
         }
         api.add_test_run_metadata(run_meta, test_run.id)
-        test_run_dict = api.get_tests_run_dicts_from_run_id(run.id)
+        test_run_dict = api.get_tests_run_dicts_from_run_id(run.uuid)
         self.assertEqual(3, len(test_run_dict['fake_test']['metadata']))
         for meta in run_meta:
             self.assertIn(meta, test_run_dict['fake_test']['metadata'])
@@ -158,7 +159,7 @@ class TestDatabaseAPI(base.TestCase):
                             datetime.datetime(1914, 6, 28, 10, 45, 0))
         api.create_test_run(test_c.id, run.id, 'success',
                             datetime.datetime(2014, 8, 26, 20, 00, 00))
-        test_run_dicts = api.get_tests_run_dicts_from_run_id(run.id)
+        test_run_dicts = api.get_tests_run_dicts_from_run_id(run.uuid)
         self.assertEqual(len(test_run_dicts), 3)
         prev = None
         for test_run in test_run_dicts:
@@ -195,9 +196,9 @@ class TestDatabaseAPI(base.TestCase):
                                         datetime.datetime.utcnow())
         testrun_c = api.create_test_run(test_a.id, run_c.id, 'success',
                                         datetime.datetime.utcnow())
-        test_runs_a = api.get_test_runs_by_run_id(run_a.id)
-        test_runs_b = api.get_test_runs_by_run_id(run_b.id)
-        test_runs_c = api.get_test_runs_by_run_id(run_c.id)
+        test_runs_a = api.get_test_runs_by_run_id(run_a.uuid)
+        test_runs_b = api.get_test_runs_by_run_id(run_b.uuid)
+        test_runs_c = api.get_test_runs_by_run_id(run_c.uuid)
         self.assertEqual(len(test_runs_a), 1)
         self.assertEqual(testrun_a.id, test_runs_a[0].id)
         self.assertEqual(testrun_a.status, test_runs_a[0].status)
@@ -214,7 +215,7 @@ class TestDatabaseAPI(base.TestCase):
         # 10 with 10 failures
         # 7 in 2010/2011 each, 6 in 2012
         # 10 in projecta/projectb each
-        for i in range(20):
+        for i in moves.range(20):
             if i % 2 == 1:
                 fails = 10
             else:
@@ -251,7 +252,7 @@ class TestDatabaseAPI(base.TestCase):
     def test_get_time_series_runs_by_key_value(self):
         runs = []
         run_at = datetime.datetime.utcnow()
-        for run_num in xrange(15):
+        for run_num in moves.range(15):
             run = api.create_run(run_num, run_num + 1, run_num + 2, 3,
                                  run_at=run_at)
             runs.append(run)
@@ -263,14 +264,14 @@ class TestDatabaseAPI(base.TestCase):
         runs_time_series = api.get_time_series_runs_by_key_value('test_key',
                                                                  'fun')
         self.assertEqual(1, len(runs_time_series))
-        timestamp = runs_time_series.keys()[0]
+        timestamp = list(runs_time_series.keys())[0]
         self.assertEqual(3, len(runs_time_series[timestamp]))
-        for run_num in xrange(3):
+        for run_num in moves.range(3):
             run_dict = {
-                'skip': long(run_num),
-                'fail': long(run_num + 1),
-                'pass': long(run_num + 2),
-                'id': unicode(runs[run_num].id),
+                'skip': run_num,
+                'fail': run_num + 1,
+                'pass': run_num + 2,
+                'id': runs[run_num].uuid,
                 'run_time': 3.0,
                 'metadata': {
                     u'test_key': u'fun',
@@ -278,12 +279,12 @@ class TestDatabaseAPI(base.TestCase):
                 }
             }
             self.assertIn(run_dict, runs_time_series[timestamp])
-        for run_num in range(3, 14):
+        for run_num in moves.range(3, 14):
             missing_run_dict = {
-                'skip': long(run_num),
-                'fail': long(run_num + 1),
-                'pass': long(run_num + 2),
-                'id': unicode(runs[run_num].id),
+                'skip': run_num,
+                'fail': run_num + 1,
+                'pass': run_num + 2,
+                'id': runs[run_num].id,
                 'run_time': 3.0,
                 'metadata': {
                     u'test_key': u'fun',
@@ -292,6 +293,17 @@ class TestDatabaseAPI(base.TestCase):
             }
             self.assertNotIn(missing_run_dict, runs_time_series[timestamp])
 
+    def test_get_test_runs_test_test_id(self):
+        run = api.create_run()
+        test_a = api.create_test('fake_test')
+        test_b = api.create_test('less_fake_test')
+        api.create_test_run(test_a.id, run.id, 'success')
+        api.create_test_run(test_b.id, run.id, 'success')
+        res = api.get_test_runs_by_test_test_id('less_fake_test')
+        self.assertEqual(1, len(res))
+        self.assertEqual(test_b.id, res[0].test_id)
+        self.assertEqual(run.id, res[0].run_id)
+
     def test_get_all_run_metadata_keys(self):
         run = api.create_run()
         meta_dict = {
@@ -373,8 +385,8 @@ class TestDatabaseAPI(base.TestCase):
         self.assertEqual(1, api.get_session().query(
             models.RunMetadata.id).count())
         self.assertEqual(run_b.id, runs[0].id)
-        self.assertEqual(1, len(api.get_run_metadata(run_b.id)))
-        self.assertEqual(0, len(api.get_run_metadata(run_a.id)))
+        self.assertEqual(1, len(api.get_run_metadata(run_b.uuid)))
+        self.assertEqual(0, len(api.get_run_metadata(run_a.uuid)))
 
     def test_delete_old_test_runs(self):
         run_a = api.create_run()
